@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1994, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1994, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -32,7 +32,7 @@ import java.util.Optional;
 
 import jdk.internal.math.FloatingDecimal;
 import jdk.internal.math.DoubleConsts;
-import jdk.internal.HotSpotIntrinsicCandidate;
+import jdk.internal.vm.annotation.IntrinsicCandidate;
 
 /**
  * The {@code Double} class wraps a value of the primitive type
@@ -46,11 +46,18 @@ import jdk.internal.HotSpotIntrinsicCandidate;
  * constants and methods useful when dealing with a
  * {@code double}.
  *
+ * <p>This is a <a href="{@docRoot}/java.base/java/lang/doc-files/ValueBased.html">value-based</a>
+ * class; programmers should treat instances that are
+ * {@linkplain #equals(Object) equal} as interchangeable and should not
+ * use instances for synchronization, or unpredictable behavior may
+ * occur. For example, in a future release, synchronization may fail.
+ *
  * @author  Lee Boynton
  * @author  Arthur van Hoff
  * @author  Joseph D. Darcy
  * @since 1.0
  */
+@jdk.internal.ValueBased
 public final class Double extends Number
         implements Comparable<Double>, Constable, ConstantDesc {
     /**
@@ -525,7 +532,7 @@ public final class Double extends Number
      * @return a {@code Double} instance representing {@code d}.
      * @since  1.5
      */
-    @HotSpotIntrinsicCandidate
+    @IntrinsicCandidate
     public static Double valueOf(double d) {
         return new Double(d);
     }
@@ -605,7 +612,7 @@ public final class Double extends Number
      * {@link #valueOf(double)} is generally a better choice, as it is
      * likely to yield significantly better space and time performance.
      */
-    @Deprecated(since="9")
+    @Deprecated(since="9", forRemoval = true)
     public Double(double value) {
         this.value = value;
     }
@@ -626,7 +633,7 @@ public final class Double extends Number
      * {@code double} primitive, or use {@link #valueOf(String)}
      * to convert a string to a {@code Double} object.
      */
-    @Deprecated(since="9")
+    @Deprecated(since="9", forRemoval = true)
     public Double(String s) throws NumberFormatException {
         value = parseDouble(s);
     }
@@ -735,7 +742,7 @@ public final class Double extends Number
      *
      * @return the {@code double} value represented by this object
      */
-    @HotSpotIntrinsicCandidate
+    @IntrinsicCandidate
     public double doubleValue() {
         return value;
     }
@@ -856,7 +863,7 @@ public final class Double extends Number
      * @param   value   a {@code double} precision floating-point number.
      * @return the bits that represent the floating-point number.
      */
-    @HotSpotIntrinsicCandidate
+    @IntrinsicCandidate
     public static long doubleToLongBits(double value) {
         if (!isNaN(value)) {
             return doubleToRawLongBits(value);
@@ -900,7 +907,7 @@ public final class Double extends Number
      * @return the bits that represent the floating-point number.
      * @since 1.3
      */
-    @HotSpotIntrinsicCandidate
+    @IntrinsicCandidate
     public static native long doubleToRawLongBits(double value);
 
     /**
@@ -964,7 +971,7 @@ public final class Double extends Number
      * @return  the {@code double} floating-point value with the same
      *          bit pattern.
      */
-    @HotSpotIntrinsicCandidate
+    @IntrinsicCandidate
     public static native double longBitsToDouble(long bits);
 
     /**
