@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -87,15 +87,6 @@ public final class GraalOptions {
     @Option(help = "The maximum length of an array that will be escape analyzed.", type = OptionType.Expert)
     public static final OptionKey<Integer> MaximumEscapeAnalysisArrayLength = new OptionKey<>(128);
 
-    @Option(help = "", type = OptionType.Debug)
-    public static final OptionKey<Boolean> PEAInliningHints = new OptionKey<>(false);
-
-    @Option(help = "", type = OptionType.Expert)
-    public static final OptionKey<Double> TailDuplicationProbability = new OptionKey<>(0.5);
-
-    @Option(help = "", type = OptionType.Expert)
-    public static final OptionKey<Integer> TailDuplicationTrivialSize = new OptionKey<>(1);
-
     @Option(help = "", type = OptionType.Expert)
     public static final OptionKey<Integer> DeoptsToDisableOptimisticOptimization = new OptionKey<>(40);
 
@@ -185,9 +176,6 @@ public final class GraalOptions {
     @Option(help = "", type = OptionType.Debug)
     public static final OptionKey<Boolean> OmitHotExceptionStacktrace = new OptionKey<>(false);
 
-    @Option(help = "", type = OptionType.Debug)
-    public static final OptionKey<Boolean> GenSafepoints = new OptionKey<>(true);
-
     @Option(help = "", type = OptionType.Debug)
     public static final OptionKey<Boolean> GenLoopSafepoints = new OptionKey<>(true);
 
@@ -210,6 +198,9 @@ public final class GraalOptions {
     @Option(help = "Generate position independent code", type = OptionType.Expert)
     public static final OptionKey<Boolean> GeneratePIC = new OptionKey<>(false);
 
+    @Option(help = "Generate verify oop checks in AOT code", type = OptionType.Expert)
+    public static final OptionKey<Boolean> AOTVerifyOops = new OptionKey<>(false);
+
     // Runtime settings
     @Option(help = "", type = OptionType.Expert)
     public static final OptionKey<Boolean> SupportJsrBytecodes = new OptionKey<>(true);
@@ -244,12 +235,6 @@ public final class GraalOptions {
     @Option(help = "", type = OptionType.Debug)
     public static final OptionKey<Boolean> OptFloatingReads = new OptionKey<>(true);
 
-    @Option(help = "", type = OptionType.Debug)
-    public static final OptionKey<Boolean> OptEliminatePartiallyRedundantGuards = new OptionKey<>(true);
-
-    @Option(help = "", type = OptionType.Debug)
-    public static final OptionKey<Boolean> OptFilterProfiledTypes = new OptionKey<>(true);
-
     @Option(help = "", type = OptionType.Debug)
     public static final OptionKey<Boolean> OptDevirtualizeInvokesOptimistically = new OptionKey<>(true);
 
@@ -289,6 +274,6 @@ public final class GraalOptions {
     @Option(help = "Alignment in bytes for loop header blocks.", type = OptionType.Expert)
     public static final OptionKey<Integer> LoopHeaderAlignment = new OptionKey<>(16);
 
-    @Option(help = "Do not include membars for volatile accesses until the end of optimizations.", type = OptionType.Expert)
-    public static final OptionKey<Boolean> LateMembars = new OptionKey<>(true);
+    @Option(help = "String.indexOf invocations will be evaluated at compile time if the receiver is a constant and its length is lower than this value.", type = OptionType.Expert)
+    public static final OptionKey<Integer> StringIndexOfLimit = new OptionKey<>(4096);
 }
