@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -306,7 +302,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "enm", "angl\u00e8s mitj\u00e0" },
             { "GM", "G\u00e0mbia" },
             { "GN", "Guinea" },
-            { "GP", "Guadeloupe" },
+            { "GP", "Guadalupe" },
             { "GQ", "Guinea Equatorial" },
             { "GR", "Gr\u00e8cia" },
             { "GS", "Illes Ge\u00f2rgia del Sud i Sandwich del Sud" },
@@ -796,7 +792,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "%%SOLBA", "dialecte de Stolvizza/Solbica" },
             { "Jpan", metaValue_ja },
             { "ar", metaValue_ar },
-            { "Hrkt", "katakana o hiragana" },
+            { "Hrkt", "sil\u00b7labaris japonesos" },
             { "as", "assam\u00e8s" },
             { "sdc", "sasser\u00e8s" },
             { "Lina", "lineal A" },
@@ -970,7 +966,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "mas", "massai" },
             { "kj", "kuanyama" },
             { "kk", "kazakh" },
-            { "kl", "grenland\u00e8s" },
+            { "kl", "groenland\u00e8s" },
             { "km", metaValue_km },
             { "kn", metaValue_kn },
             { "ko", metaValue_ko },
