@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -111,7 +107,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "type.ca.ethiopic", "kalendarz etiopski" },
             { "glk", "gilia\u0144ski" },
             { "AI", "Anguilla" },
-            { "key.tz", "Strefa czasowa" },
+            { "key.tz", "strefa czasowa" },
             { "AL", "Albania" },
             { "AM", "Armenia" },
             { "Teng", "tengwar" },
@@ -123,14 +119,14 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "AT", "Austria" },
             { "AU", "Australia" },
             { "AW", "Aruba" },
-            { "en_US", "ameryka\u0144ski angielski" },
+            { "en_US", "angielski ameryka\u0144ski" },
             { "AX", "Wyspy Alandzkie" },
             { "mye", "myene" },
             { "AZ", "Azerbejd\u017can" },
             { "%%AREVELA", "ormia\u0144ski wchodni" },
             { "BA", "Bo\u015bnia i Hercegowina" },
             { "BB", "Barbados" },
-            { "ceb", "cebuano" },
+            { "ceb", "cebua\u0144ski" },
             { "BD", "Bangladesz" },
             { "kum", "kumycki" },
             { "BE", "Belgia" },
@@ -242,7 +238,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "FJ", "Fid\u017ci" },
             { "FK", "Falklandy" },
             { "FM", "Mikronezja" },
-            { "key.va", "Wariant regionalny" },
+            { "key.va", "wariant regionalny" },
             { "FO", "Wyspy Owcze" },
             { "Taml", "tamilskie" },
             { "FR", "Francja" },
@@ -286,7 +282,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "zxx", "brak tre\u015bci o charakterze j\u0119zykowym" },
             { "tly", "ta\u0142yski" },
             { "pdt", "plautdietsch" },
-            { "de_AT", "austriacki niemiecki" },
+            { "de_AT", "niemiecki austriacki" },
             { "HK", "SRA Hongkong (Chiny)" },
             { "Vaii", "vai" },
             { "HM", "Wyspy Heard i McDonalda" },
@@ -336,7 +332,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "tog", "tonga (Niasa)" },
             { "type.nu.knda", "cyfry kannada" },
             { "Kali", "kayah li" },
-            { "de_CH", "szwajcarski wysokoniemiecki" },
+            { "de_CH", "wysokoniemiecki szwajcarski" },
             { "type.co.phonetic", "sortowanie fonetyczne" },
             { "izh", "ingryjski" },
             { "type.ca.buddhist", "kalendarz buddyjski" },
@@ -349,11 +345,11 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "Knda", metaValue_kn },
             { "KN", "Saint Kitts i Nevis" },
             { "Zinh", "dziedziczone" },
-            { "fr_CA", "kanadyjski francuski" },
+            { "fr_CA", "francuski kanadyjski" },
             { "KP", "Korea P\u00f3\u0142nocna" },
             { "KR", "Korea Po\u0142udniowa" },
             { "Plrd", "fonetyczny Pollard\u2019a" },
-            { "fr_CH", "szwajcarski francuski" },
+            { "fr_CH", "francuski szwajcarski" },
             { "KW", "Kuwejt" },
             { "tpi", "tok pisin" },
             { "KY", "Kajmany" },
@@ -455,7 +451,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "PA", "Panama" },
             { "type.ca.islamic-civil", "kalendarz islamski (metoda obliczeniowa)" },
             { "csb", "kaszubski" },
-            { "en_GB", "brytyjski angielski" },
+            { "en_GB", "angielski brytyjski" },
             { "PE", "Peru" },
             { "ttt", "tacki" },
             { "PF", "Polinezja Francuska" },
@@ -718,7 +714,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "lun", "lunda" },
             { "nyo", "nyoro" },
             { "luo", "luo" },
-            { "fil", "filipino" },
+            { "fil", "filipi\u0144ski" },
             { "hmn", "hmong" },
             { "del", "delaware" },
             { "lus", "mizo" },
@@ -1053,7 +1049,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "kea", "kreolski Wysp Zielonego Przyl\u0105dka" },
             { "mic", "mikmak" },
             { "suk", "sukuma" },
-            { "en_AU", "australijski angielski" },
+            { "en_AU", "angielski australijski" },
             { "sa", "sanskryt" },
             { "%%UCCOR", "ortografia ujednolicona" },
             { "sc", "sardy\u0144ski" },
@@ -1096,7 +1092,7 @@ public class LocaleNames_pl extends OpenListResourceBundle {
             { "ti", "tigrinia" },
             { "bug", "bugijski" },
             { "kfo", "koro" },
-            { "en_CA", "kanadyjski angielski" },
+            { "en_CA", "angielski kanadyjski" },
             { "tk", "turkme\u0144ski" },
             { "tl", "tagalski" },
             { "tn", "setswana" },
