@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -106,7 +102,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "AO", "\u0627\u0646\u06ab\u0648\u0644\u0627" },
             { "AQ", "\u0627\u0646\u062a\u0627\u0631\u06a9\u062a\u06cc\u06a9\u0627" },
             { "AR", "\u0627\u0631\u062c\u0646\u067c\u0627\u064a\u0646" },
-            { "AS", "\u0627\u0645\u0631\u06cc\u06a9\u0627\u06cc\u06cc \u0633\u0645\u0648" },
+            { "AS", "\u0627\u0645\u0631\u06cc\u06a9\u0627\u06cc\u06cc \u0633\u0627\u0645\u0627\u0648\u0627" },
             { "AT", "\u0627\u062a\u0631\u06cc\u0634" },
             { "AU", "\u0622\u0633\u067c\u0631\u0627\u0644\u06cc\u0627" },
             { "AW", "\u0622\u0631\u0648\u0628\u0627" },
@@ -219,8 +215,8 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "GL", "\u06ab\u0631\u06cc\u0646\u0644\u06cc\u0646\u0689" },
             { "GM", "\u06ab\u0627\u0645\u0628\u06cc\u0627" },
             { "GN", "\u06ab\u06cc\u0646\u0647" },
-            { "GP", "\u06ab\u0627\u0644\u0689\u06cc\u067e" },
-            { "GQ", "\u0627\u0633\u062a\u0648\u0627\u06cc\u06cc \u06ab\u06cc\u0646\u0647" },
+            { "GP", "\u06ab\u0648\u0627\u062f\u0644\u0648\u067e" },
+            { "GQ", "\u0627\u0633\u062a\u0648\u0627\u06cc\u06cc \u06ab\u06cc\u0646\u064a" },
             { "GR", "\u06cc\u0648\u0646\u0627\u0646" },
             { "GS", "\u0633\u0648\u064a\u0644\u064a \u062c\u0627\u0631\u062c\u064a\u0627 \u0627\u0648 \u0633\u0648\u064a\u0644\u064a \u0633\u06d0\u0646\u0689\u0648\u0686 \u067c\u0627\u067e\u0648\u06ab\u0627\u0646" },
             { "GT", "\u06ab\u0648\u0627\u062a\u06cc\u0645\u0627\u0644\u0627" },
@@ -248,7 +244,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "IL", "\u0627\u0633\u0631\u0627\u064a\u064a\u0644" },
             { "IM", "\u062f \u0622\u0626\u0644 \u0622\u0641 \u0645\u06cc\u0646" },
             { "IN", "\u0647\u0646\u062f" },
-            { "IO", "\u062f \u0628\u0631\u064a\u062a\u0627\u0646\u0648\u064a \u0647\u0646\u062f \u0633\u0645\u0646\u062f\u0631\u064a \u0633\u064a\u0645\u0647" },
+            { "IO", "\u062f \u0628\u0631\u062a\u0627\u0646\u0648\u064a \u0647\u0646\u062f \u0633\u0645\u0646\u062f\u0631\u064a \u0633\u064a\u0645\u0647" },
             { "IQ", "\u0639\u0631\u0627\u0642" },
             { "IR", "\u0627\u064a\u0631\u0627\u0646" },
             { "IS", "\u0622\u06cc\u0633\u0644\u06cc\u0646\u0689" },
@@ -265,7 +261,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "ain", "\u0627\u064a\u0646\u0648\u064a\u064a" },
             { "guz", "\u06ab\u0648\u0633\u064a" },
             { "type.nu.knda", "\u06a9\u0627\u0646\u0627\u0689\u0627 \u064a\u064a \u0627\u0639\u062f\u0627\u062f" },
-            { "de_CH", "\u0633\u0648\u0626\u0633 \u0644\u0648\u06cc \u062c\u0631\u0645\u0646" },
+            { "de_CH", "\u0633\u0648\u06cc\u0633 \u0647\u0627\u06cc \u062c\u0631\u0645\u0646" },
             { "type.ca.buddhist", "\u0628\u0648\u062f\u0627\u064a\u064a \u062c\u0646\u062a\u0631\u064a" },
             { "KE", "\u06a9\u06cc\u0646\u06cc\u0627" },
             { "419", "\u0644\u0627\u062a\u06cc\u0646\u064a \u0627\u0645\u0631\u06cc\u06a9\u0627" },
@@ -316,7 +312,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "MM", "\u0645\u064a\u0627\u0646\u0645\u0627\u0631 (\u0628\u0631\u0645\u0627)" },
             { "MN", "\u0645\u0646\u06ab\u0648\u0644\u064a\u0627" },
             { "new", "\u0646\u064a\u0648\u0627\u0631\u064a" },
-            { "MO", "\u0645\u06a9\u0627\u0648 \u0633\u0627\u0631 \u0686\u06cc\u0646" },
+            { "MO", "\u0645\u06a9\u0627\u0648 SAR \u0686\u06cc\u0646" },
             { "MP", "\u0634\u0645\u0627\u0644\u064a \u0645\u0627\u0631\u064a\u0627\u0646\u0627 \u067c\u0627\u067e\u0648\u06ab\u0627\u0646" },
             { "MQ", "\u0645\u0627\u0631\u067c\u06cc\u0646\u06cc\u06a9" },
             { "MR", "\u0645\u0648\u0631\u06cc\u062a\u0627\u0646\u06cc\u0627" },
@@ -334,7 +330,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "202", "\u0633\u0628 \u0633\u0647\u0627\u0631\u0646 \u0627\u0641\u0631\u064a\u0642\u0627" },
             { "type.ca.hebrew", "\u062c\u0648\u0631\u062c\u0648\u06cc\u0627\u0646 \u062c\u0646\u062a\u0631\u064a" },
             { "NC", "\u0646\u0648\u06cc \u06a9\u0627\u0644\u06cc\u0689\u0648\u0646\u06cc\u0627" },
-            { "NE", "\u0646\u06cc\u062c\u0631" },
+            { "NE", "\u0646\u0627\u064a\u062c\u064a\u0631" },
             { "NF", "\u0646\u0627\u0631\u0641\u0648\u0644\u06a9 \u067c\u0627\u067e\u0648\u06ab\u0627\u0646" },
             { "NG", "\u0646\u0627\u06cc\u062c\u06cc\u0631\u06cc\u0627" },
             { "trv", "\u062a\u0627\u0631\u0648\u06a9\u0648" },
@@ -362,7 +358,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "PM", "\u0633\u06cc\u0646\u067c \u067e\u06cc\u06cc\u0631 \u0627\u0648 \u0645\u06cc\u06a9\u0648\u0644\u0648\u0646" },
             { "PN", "\u067e\u064a\u067c\u06a9\u064a\u0631\u0646 \u067c\u0627\u067e\u0648\u06ab\u0627\u0646" },
             { "PR", "\u067e\u0648\u0631\u062a\u0648 \u0631\u06cc\u06a9\u0648" },
-            { "PS", "\u0641\u0644\u0633\u0637\u064a\u0646 \u0633\u064a\u0645\u06d0" },
+            { "PS", "\u0641\u0644\u0633\u0637\u06cc\u0646\u064a \u0633\u064a\u0645\u06d0" },
             { "PT", "\u067e\u0648\u0631\u062a\u06ab\u0627\u0644" },
             { "PW", "\u067e\u0644\u0627\u0624" },
             { "nia", "\u0646\u064a\u0627\u0633" },
@@ -480,11 +476,11 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "jgo", "\u0646\u06ab\u0648\u0645\u0628\u0627" },
             { "lkt", "\u0644\u06a9\u0648\u067c\u0627" },
             { "wae", "\u0648\u0644\u0633\u06cc\u0631" },
-            { "WS", "\u0633\u0627\u0645\u0648\u0627" },
+            { "WS", "\u0633\u0627\u0645\u0627\u0648\u0627" },
             { "wal", "\u0648\u0644\u0627\u06cc\u067c\u0627" },
             { "XA", "\u062c\u0639\u0644\u064a \u062e\u062c" },
             { "war", "\u0648\u0627\u0631\u06cd" },
-            { "XB", "\u062c\u0639\u0644\u064a \u0628\u064a\u062f\u064a" },
+            { "XB", "\u0633\u06cc\u0689\u0648 \u0628\u06cc\u0689\u06cc" },
             { "awa", "\u0627\u0648\u0627\u062f\u064a" },
             { "061", "\u067e\u0648\u0644\u0646\u064a\u0633\u064a\u0627" },
             { "XK", "\u06a9\u0648\u0633\u0648\u0648" },
@@ -492,7 +488,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "Zxxx", "\u0646\u0627\u0644\u064a\u06a9\u0644\u06cc" },
             { "YE", "\u06cc\u0645\u0646" },
             { "nqo", "\u0646\u06a9\u0648" },
-            { "type.co.standard", "\u0645\u0639\u064a\u0627\u0631\u064a \u062f \u0644\u067c\u06d0 \u062a\u0631\u062a\u064a\u0628" },
+            { "type.co.standard", "\u062f \u0645\u0639\u06cc\u0627\u0631\u064a \u0644\u067c\u064a \u062a\u0631\u062a\u06cc\u0628" },
             { "YT", "\u0645\u0627\u064a\u0648\u067c" },
             { "ZA", "\u0633\u0648\u06cc\u0644\u064a \u0627\u0641\u0631\u06cc\u0642\u0627" },
             { "type.lb.loose", "\u062f \u063a\u0693\u0646\u062f\u06d0 \u0645\u0627\u062a\u06d0 \u06a9\u0631\u069a\u06d0 \u0689\u0648\u0644" },
@@ -635,7 +631,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "bin", "\u0628\u06cc\u0646\u06cc" },
             { "hr", "\u06a9\u0631\u0648\u0627\u064a\u0634\u064a\u0627\u064a\u064a" },
             { "ht", "\u0647\u064a\u067c\u064a \u06a9\u0631\u064a\u0648\u0644" },
-            { "hu", "\u0647\u0646\u06af\u0631\u064a" },
+            { "hu", "\u0647\u0646\u06ab\u0631\u064a" },
             { "hy", "\u0622\u0631\u0645\u064a\u0646\u064a\u0627\u064a\u064a" },
             { "hz", "\u0647\u06cc\u0631\u0648\u0631\u0648" },
             { "ia", "\u0627\u0646\u067c\u0631\u0644\u0646\u06ab\u0648\u0627" },
@@ -685,6 +681,7 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "ln", "\u0644\u0646\u06ab\u0627\u0644\u0627" },
             { "fur", "\u0641\u0631\u0627\u0626\u06cc\u0644\u06cc\u06cc\u0646" },
             { "lo", "\u0644\u0627\u0648" },
+            { "type.ms.uksystem", "\u0627\u0645\u067e\u064a\u0631\u064a\u0644 \u062f \u0646\u0627\u067e \u0646\u0638\u0627\u0645" },
             { "lt", "\u0644\u064a\u062a\u0648\u0627\u0646\u064a" },
             { "lu", "\u0644\u0648\u0628\u0627-\u06a9\u067c\u0646\u06ab\u0627" },
             { "lv", "\u0644\u06d0\u067c\u0648\u0627\u0646\u064a" },
@@ -704,12 +701,13 @@ public class LocaleNames_ps extends OpenListResourceBundle {
             { "dsb", "\u06a9\u069a\u062a\u0647 \u0633\u0631\u0628\u064a\u0627\u064a\u064a" },
             { "na", metaValue_NR },
             { "type.co.search", "\u062f \u0639\u0645\u0648\u0645\u064a \u0645\u0648\u062e\u064a \u0644\u067c\u0648\u0646" },
-            { "nb", "\u0646\u0627\u0631\u0648\u06d0 \u0628\u0648\u06a9\u0645\u0627\u0644" },
+            { "nb", "\u0646\u0627\u0631\u0648\u06d0\u0626\u064a (\u0628\u0648\u06a9\u0645\u0627\u0644)" },
             { "nd", "\u0634\u0645\u0627\u0644\u064a \u0646\u062f\u064a\u0628\u0644" },
             { "ne", "\u0646\u06d0\u067e\u0627\u0644\u064a" },
             { "ng", "\u0646\u062f\u0648\u0646\u06af\u0627" },
             { "nl", "\u0647\u0627\u0644\u06d0\u0646\u0689\u064a" },
             { "nn", "\u0646\u0627\u0631\u0648\u06d0\u0626\u064a (\u0646\u0627\u0626\u0646\u0648\u0631\u0633\u06a9)" },
+            { "no", "\u0646\u0627\u0631\u0648\u06d0\u0626\u064a" },
             { "nr", "\u0633\u0648\u064a\u0644\u064a \u0646\u062f\u064a\u0628\u064a\u0644" },
             { "nv", "\u0646\u0648\u0627\u062c\u0648" },
             { "ny", "\u0646\u06cc\u0627\u0646\u062c\u0627" },
