@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -248,15 +244,15 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "MA", "Marokko" },
             { "MC", "Monako" },
             { "MD", "Moldowa" },
-            { "ME", "Montenegro" },
+            { "ME", "\u00c7ernogori\u00fda" },
             { "MF", "Sen-Marten" },
             { "MG", "Madagaskar" },
             { "MH", "Mar\u015fall adalary" },
             { "MK", "Demirgazyk Makedoni\u00fda" },
             { "ML", "Mali" },
-            { "MM", "M\u00fdanma (Burma)" },
+            { "MM", "M\u00fdanma (Birma)" },
             { "MN", "Mongoli\u00fda" },
-            { "MO", "Makau AAS Hyta\u00fd" },
+            { "MO", "Makao AAS Hyta\u00fd" },
             { "MP", "Demirgazyk Mariana adalary" },
             { "MQ", "Martinika" },
             { "MR", "Mawritani\u00fda" },
@@ -384,7 +380,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "bn", "bengal dili" },
             { "bo", "tibet dili" },
             { "br", "breton dili" },
-            { "bs", "bo\u015fnak dili" },
+            { "bs", "bosni\u00fda dili" },
             { "ca", "katalan dili" },
             { "ce", "\u00e7e\u00e7en dili" },
             { "ch", "\u00e7amorro" },
@@ -614,7 +610,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "kea", "kabuwerdianu dili" },
             { "kfo", "koro dili" },
             { "kha", "khasi dili" },
-            { "khq", "ko\u00fdra-\u00c7ini dili" },
+            { "khq", "ko\u00fdra-\u00e7ini dili" },
             { "kkj", "kako dili" },
             { "kln", "kalenjin dili" },
             { "kmb", "kimbundu dili" },
@@ -677,7 +673,7 @@ public class LocaleNames_tk extends OpenListResourceBundle {
             { "pam", "kapampangan dili" },
             { "pap", "pap\u00fdamento dili" },
             { "pau", "palau dili" },
-            { "pcm", "nigeri\u00fd-pijin dili" },
+            { "pcm", "nigeri\u00fda-pijin dili" },
             { "prg", "prussi\u00fda dili" },
             { "quc", "ki\u00e7e dili" },
             { "rap", "rapanu\u00fd dili" },
